package framework.session.bean;

import java.util.Collection;

import javax.ejb.Local;
import javax.ejb.Remote;
import javax.ejb.Stateless;
import javax.persistence.EntityManager;
import javax.persistence.PersistenceContext;

import framework.entity.Parametre;
import framework.session.local.ParametreLocal;
import framework.session.remote.ParametreRemote;

import org.jboss.ejb3.annotation.Clustered;
import org.jboss.ejb3.annotation.SecurityDomain;
import org.jboss.logging.Logger;

@Stateless
@Clustered
@Remote(value = ParametreRemote.class)
@Local(value = ParametreLocal.class)
@SecurityDomain(value = "gi-security")
public class ParametreSB implements ParametreRemote, ParametreLocal {
	private static final Logger LOG = Logger.getLogger(ParametreSB.class);

	@PersistenceContext(unitName = "Framework")
	private EntityManager em;

	public Parametre create(Parametre info) {
		return em.merge(info);
	}

	public Parametre update(Parametre info) {
		return em.merge(info);
	}

	public void update(Collection<Parametre> col) {
		for (Parametre param : col) {
			em.merge(param);
		}
	}

	public void delete(Parametre info) {
		em.remove(em.merge(info));
	}

	public Parametre get(String id) {
		try {
			return em.find(Parametre.class, id);
		} catch (Exception e) {
			LOG.warn("Parametre " + id + " not found", e);
			return null;
		}
	}

	public Collection<Parametre> findAll() {
		return em.createNamedQuery("FIND_ALL_PARAM", Parametre.class)
				.getResultList();
	}

	public Collection<Parametre> getParametresBeginWith(String id) {
		return em.createNamedQuery("FIND_ALL_BEGIN_WITH", Parametre.class)
				.setParameter("id", id + "%").getResultList();
	}

	public void updateParamBatchCommRecept(Parametre emailSA,
			Collection<Parametre> emailCD, Parametre periodicite,
			Parametre nbJour) {
		update(emailSA);
		update(periodicite);
		update(nbJour);
		for (Parametre pi : emailCD) {
			update(pi);
		}
	}

}
